#
# gets the data from the virustracker.com via a REST call
#

import requests
import pandas as pd

def get_covid_country_data():

  #download the data from he virustracker
  res = requests.get('https://api.thevirustracker.com/free-api?countryTotals=ALL')
  data = res.json()

  # prepare the country data as a dataframe
  country_data = data['countryitems'][0]
  df = pd.DataFrame(country_data).transpose()
  df = df.drop('stat') # remove the row 'stats'
  df.index.astype('int64') # make the index an integer
  df = df.drop(columns=['source', 'ourid']) # drop columns id, souurce, ourid
  # rename the countries for folium
  df.replace('USA', "United States of America", inplace = True)
  df.replace('Tanzania', "United Republic of Tanzania", inplace = True)
  df.replace('Democratic Republic of Congo', "Democratic Republic of the Congo", inplace = True)
  df.replace('Congo', "Republic of the Congo", inplace = True)
  df.replace('Lao', "Laos", inplace = True)
  df.replace('Syrian Arab Republic', "Syria", inplace = True)
  df.replace('Serbia', "Republic of Serbia", inplace = True)
  df.replace('Czechia', "Czech Republic", inplace = True)
  df.replace('UAE', "United Arab Emirates", inplace = True)
  # change title column to country column, so its easier to access when processing
  df = df.rename(columns={'title':'country'})
  return df



from __future__ import print_function
from cloudmesh.shell.command import command
from cloudmesh.shell.command import PluginCommand
from cloudmesh.covid.api.manager import Manager
from cloudmesh.common.console import Console
from cloudmesh.common.util import path_expand
from pprint import pprint
from cloudmesh.common.debug import VERBOSE

class CovidCommand(PluginCommand):

    # noinspection PyUnusedLocal
    @command
    def do_covid(self, args, arguments):
        """
        ::

          Usage:
                covid --file=FILE
                covid list

          This command does some useful things.

          Arguments:
              FILE   a file name

          Options:
              -f      specify the file

        """
        arguments.FILE = arguments['--file'] or None

        VERBOSE(arguments)

        m = Manager()

        if arguments.FILE:
            print("option a")
            m.list(path_expand(arguments.FILE))

        elif arguments.list:
            print("option b")
            m.list("just calling list without parameter")

        Console.error("This is just a sample")
        return ""
